@@ -6,6 +6,7 @@
 #' widening the data.
 #'
 #' @export
+#' @family basic
 #' @param data A `data.frame` or containing the action/event data.
 #' @param actor A `character` string giving the name of the column that
 #' represents a user/actor identifier. If not provided and neither `time` nor
@@ -43,21 +44,8 @@
 #' top sessions and user by activities.
 #'
 #' @examples
-#' data <- tibble::tibble(
-#'   user = c("A", "A", "A", "B", "B", "C", "C", "C"),
-#'   time = c(
-#'     "2023-01-01 10:00:00", "2023-01-01 10:05:00",
-#'     "2023-01-01 10:20:00", "2023-01-01 12:00:00",
-#'     "2023-01-01 12:02:00", "2023-01-01 14:00:00",
-#'     "2023-01-01 14:05:00", "2023-01-01 14:10:00"
-#'   ),
-#'   action = c(
-#'     "view", "click", "add_cart", "view",
-#'     "checkout", "view", "click", "share"
-#'    )
-#' )
 #' results <- prepare_data(
-#'   data, actor = "user", time = "time", action = "action"
+#'   group_regulation_long, actor = "Actor", time = "Time", action = "Action"
 #' )
 #' print(results$sequence_data)
 #' print(results$meta_data)
@@ -80,7 +68,8 @@
 #'
 #' data_single_session <- tibble::tibble(
 #'   action = c(
-#'     "view", "click", "add_cart", "view", "checkout", "view", "click", "share"
+#'     "view", "click", "add_cart", "view",
+#'     "checkout", "view", "click", "share"
 #'    )
 #' )
 #' results_single <- prepare_data(data_single_session, action = "action")
@@ -93,6 +82,7 @@ prepare_data <- function(data, actor, time, action, order,
                          is_unix_time = FALSE, unix_time_unit = "seconds",
                          unused_fn = dplyr::first) {
   check_missing(data)
+  check_class(data, "data.frame")
   check_missing(action)
   check_string(actor)
   check_string(time)
@@ -106,14 +96,18 @@ prepare_data <- function(data, actor, time, action, order,
   .session_id <- .session_nr <- .new_session <- .time_gap <-
     .standardized_time <- .sequence <- n_sessions <- n_actions <- NULL
 
-  message_("\fInitializing session computation...")
+  rlang_verbose <- getOption("rlib_message_verbosity")
+  onlyif(
+    is.null(rlang_verbose) || isTRUE(rlang_verbose == "verbose"),
+    cli::cli_rule(left = "Preparing Data")
+  )
   message_(
-    "\fInput data dimensions:
-    {.val {nrow(data)}} rows, {.val {ncol(data)}} columns"
+    c(
+      `i` = "Input data dimensions:
+      {.val {nrow(data)}} rows, {.val {ncol(data)}} columns"
+    )
   )
   data <- tibble::as_tibble(data)
-
-  # Column validation
   cols_req <- c(
     action,
     onlyif(!missing(actor), actor),
@@ -125,8 +119,9 @@ prepare_data <- function(data, actor, time, action, order,
   stopifnot_(
     all(cols_obs),
     c(
-      "\fThe columns {.val {cols_req}} must exist in the data.",
-      `x` = "The following columns were not found in the data: {cols_mis}."
+      "The columns {.val {cols_req}} must exist in the data.",
+      `x` = "The following columns were
+             not found in the data: {.val {cols_mis}}."
     )
   )
   long_data <- data
@@ -145,13 +140,15 @@ prepare_data <- function(data, actor, time, action, order,
     default_order <- TRUE
   }
   if (!missing(time)) {
-    message_("\fParsing time values...")
     message_(
-      "\fFirst few time values: {.val {utils::head(data[[time]], 3)}}"
+      c(`i` = "First few time values: {.val {utils::head(data[[time]], 3)}}")
     )
     if (is.numeric(data[[time]])) {
       message_(
-        "\fDetected {.cls numeric} time values - treating as Unix timestamp."
+        c(
+          `i` = "Detected {.cls numeric} time values:
+          treating as Unix timestamp."
+        )
       )
       is_unix_time <- TRUE
     }
@@ -161,12 +158,12 @@ prepare_data <- function(data, actor, time, action, order,
       is_unix_time = is_unix_time,
       unix_time_unit = unix_time_unit
     )
-    message_("\fSample of parsed times: {.val {utils::head(parsed_times, 3)}}")
-    message_("\fCreating sessions based on time threshold...")
     message_(
-      "\fTime threshold for new session: {.val {time_threshold}} seconds"
+      c(`i` = "Sample of parsed times: {.val {utils::head(parsed_times, 3)}}")
+    )
+    message_(
+      c(`i` = "Time threshold for new session: {.val {time_threshold}} seconds")
     )
-    # Create processed data (long format)
     long_data <- long_data |>
       dplyr::mutate(.standardized_time = parsed_times) |>
       dplyr::arrange(
@@ -201,7 +198,7 @@ prepare_data <- function(data, actor, time, action, order,
     msg <- ifelse_(
       default_order,
       paste0(
-        "\fNo {.arg time} or {.arg order} column provided. ",
+        "No {.arg time} or {.arg order} column provided. ",
         ifelse_(
           default_actor,
           "Treating the entire dataset as one session.",
@@ -210,7 +207,7 @@ prepare_data <- function(data, actor, time, action, order,
       ),
       "Using provided {.arg order} column to create sequences."
     )
-    message_(msg)
+    message_(c(`i` = msg))
     long_data <- long_data |>
       dplyr::arrange(
         !!rlang::sym(actor),
@@ -229,9 +226,6 @@ prepare_data <- function(data, actor, time, action, order,
   if (default_order) {
     long_data$.order <- NULL
   }
-
-  # Create wide format
-  message_("\fCreating wide format view of sessions...")
   wide_data <- long_data |>
     tidyr::pivot_wider(
       id_cols = .session_id,
@@ -267,37 +261,46 @@ prepare_data <- function(data, actor, time, action, order,
   if (!missing(time)) {
     stats$time_range <- range(long_data$.standardized_time)
   }
-
-  # Print summary statistics
-  rlang_verbose <- getOption("rlib_message_verbosity")
-  message_("\fSession Analysis Summary")
-  message_("\f------------------------")
-  message_("\fTotal number of sessions: {.val {stats$total_sessions}}")
+  message_(c(`i` = "Total number of sessions: {.val {stats$total_sessions}}"))
   if (!default_actor) {
-    message_("\fNumber of unique users: {.val {stats$unique_users}}")
+    message_(c(`i` = "Number of unique users: {.val {stats$unique_users}}"))
   }
-  message_("\fTotal number of actions: {.val {stats$total_actions}}")
+  message_(c(`i` = "Total number of actions: {.val {stats$total_actions}}"))
   message_(
-    "\fMaximum sequence length: {.val {stats$max_sequence_length}} actions"
+    c(
+      `i` = "Maximum sequence length:
+      {.val {stats$max_sequence_length}} actions"
+    )
   )
   if (!missing(time) && default_order) {
     message_(
-      "\fTime range: {.val {stats$time_range[1]}} to
-      {.val {stats$time_range[2]}}"
+      c(
+        `i` = "Time range: {.val {stats$time_range[1]}} to
+        {.val {stats$time_range[2]}}"
+      )
     )
   }
-  if (!default_actor) {
-    message_("\fSessions per user:")
-    onlyif(
-      is.null(rlang_verbose) || isTRUE(rlang_verbose == "verbose"),
-      print(stats$sessions_per_user)
-    )
-  }
-  message_("\fTop 5 longest sessions:")
-  onlyif(
-    is.null(rlang_verbose) || isTRUE(rlang_verbose == "verbose"),
-    print(utils::head(stats$actions_per_session, 5))
-  )
+  # if (!default_actor) {
+  #   message_(c(`i` = "Sessions per user:"))
+  #   for (i in seq_len(nrow(stats$sessions_per_user))) {
+  #     msg <- paste0(
+  #       stats$sessions_per_user[[actor]][i],
+  #       ": ",
+  #       "{.val {", stats$sessions_per_user$n_sessions[i], "}}"
+  #     )
+  #     message_(c(` ` = msg))
+  #   }
+  # }
+  # message_(c(`i` = "Top 5 longest sessions:"))
+  # max_rows <- min(nrow(stats$actions_per_session), 5L)
+  # for (i in seq_len(max_rows)) {
+  #   msg <- paste0(
+  #     stats$actions_per_session$.session_id[i],
+  #     ": ",
+  #     "{.val {", stats$actions_per_session$n_actions[i], "}}"
+  #   )
+  #   message_(c(` ` = msg))
+  # }
   structure(
     list(
       long_data = long_data,
@@ -317,12 +320,12 @@ prepare_data <- function(data, actor, time, action, order,
 #' values and treats them as NA
 #'
 #' @param time A `vector` of time values.
+#' @return A `POSIXct` object.
 #' @inheritParams prepare_data
 #' @noRd
 parse_time <- function(time, custom_format, is_unix_time, unix_time_unit) {
-  message_("\fStarting time parsing process...")
-  message_("\fNumber of values to parse: {.val {length(time)}}")
-  message_("\fSample values: {.val {utils::head(time, 3)}}")
+  message_(c(`i` = "Number of values to parse: {.val {length(time)}}"))
+  message_(c(`i` = "Sample values: {.val {utils::head(time, 3)}}"))
   # Handle Unix timestamps
   time_original <- time
   if (is.numeric(time) && is_unix_time) {
@@ -341,7 +344,9 @@ parse_time <- function(time, custom_format, is_unix_time, unix_time_unit) {
   time_empty <- is.na(time) | !nzchar(time)
   if (any(time_empty)) {
     message_(
-      "Found missing or empty time values; these will be treated as NA."
+      c(
+        `i` = "Found missing or empty time values; these will be treated as NA."
+      )
     )
     time[time_empty] <- NA
   }
@@ -354,7 +359,7 @@ parse_time <- function(time, custom_format, is_unix_time, unix_time_unit) {
   if (!is.null(custom_format)) {
     parsed_time <- as.POSIXct(strptime(time, format = custom_format))
     if (!all(is.na(parsed_time))) {
-      message_("Successfully parsed using custom format.")
+      message_(c(`v` = "Successfully parsed using custom format."))
       return(parsed_time)
     }
   }
@@ -430,19 +435,20 @@ parse_time <- function(time, custom_format, is_unix_time, unix_time_unit) {
   for (fmt in formats) {
     parsed_time <- as.POSIXct(strptime(time, format = fmt))
     if (!all(is.na(parsed_time))) {
-      message_("\fSuccessfully parsed using format: {.val {fmt}}")
-      message_("\fSample parsed time: {.val {format(parsed_time[1])}}")
+      message_(c(`v` = "Successfully parsed using format: {.val {fmt}}"))
       return(parsed_time)
     }
   }
 
   # Finally, try Unix time
   message_(
-    "Unable to parse using supported formats.
-    Trying to convert to {.cls numeric} and assuming Unix time."
+    c(
+      `x` = "Unable to parse using supported formats.
+      Trying to convert to {.cls numeric} and assuming Unix time."
+    )
   )
   # TODO suppress for now
-  time <- suppressWarnings(try(as.numeric(time), silent = TRUE))
+  time <- suppressWarnings(try_(as.numeric(time)))
   if (!inherits(time, "try-error") && all(!is.na(time))) {
     parsed_time <- switch(
       unix_time_unit,
@@ -474,3 +480,124 @@ parse_time <- function(time, custom_format, is_unix_time, unix_time_unit) {
     )
   )
 }
+
+#' Import Wide Format Sequence Data as Long Format Sequence Data
+#'
+#' This function transforms wide format data where features are in separate
+#' columns into a long format suitable for sequence analysis. It creates
+#' windows of data based on row order and generates sequence order within
+#' these windows.
+#'
+#' @export
+#' @family basic
+#' @param data A `data.frame` in wide format.
+#' @param cols An `expression` giving a tidy selection of column names to be
+#' transformed into long format (actions). This can be a vector of column names
+#' (e.g., `c(feature1, feature2)`) or a range  specified as `feature1:feature6`
+#' (without quotes) to include all columns from 'feature1' to 'feature6'
+#' in the order they appear in the data frame. For more information on
+#' tidy selections, see [dplyr::select()].
+#' @param id_cols A `character` vector of column names that uniquely identify
+#' each observation (IDs).
+#' @param window_size An `integer` specifying the size of the window for
+#' sequence grouping. Default is 1 (each row is a separate window).
+#' @param replace_zeros A `logical` value indicating whether to replace 0s
+#' in `cols` with `NA`. The default is `TRUE`.
+#' @return A `data.frame` in long format with added columns for window and
+#' sequence order.
+#' @examples
+#' data <- data.frame(
+#'   ID = c("A", "A", "B", "B"),
+#'   Time = c(1, 2, 1, 2),
+#'   feature1 = c(10, 0, 15, 20),
+#'   feature2 = c(5, 8, 0, 12),
+#'   feature3 = c(2, 4, 6, 8),
+#'   other_col = c("X", "Y", "Z", "W")
+#' )
+#'
+#' # Using a vector
+#' long_data1 <- import_data(
+#'   data = data,
+#'   cols = c(feature1, feature2),
+#'   id_cols = c("ID", "Time"),
+#'   window_size = 2,
+#'   replace_zeros = TRUE
+#' )
+#'
+#' # Using a column range
+#' long_data2 <- import_data(
+#'   data = data,
+#'   cols = feature1:feature3,
+#'   id_cols = c("ID", "Time"),
+#'   window_size = 2,
+#'   replace_zeros = TRUE
+#' )
+#'
+import_data <- function(data, cols, id_cols,
+                        window_size = 1, replace_zeros = TRUE) {
+  check_missing(data)
+  check_class(data, "data.frame")
+  check_flag(replace_zeros)
+  data_names <- colnames(data)
+  missing_ids <- id_cols[!id_cols %in% colnames(data)]
+  stopifnot_(
+    length(missing_ids) == 0L,
+    c(
+      "All ID columns specified by {.arg id_cols} must be present in the data.",
+      `x` = "The following column{?s} {?was/were} not found: {missing_ids}."
+    )
+  )
+  expr_cols <- rlang::enquo(cols)
+  pos <- tidyselect::eval_select(expr_cols, data = data)
+  cols <- names(pos)
+  out <- data
+  n <- nrow(out)
+  rownames(out) <- ifelse_(
+    is.null(rownames(data)),
+    seq_len(n),
+    rownames(data)
+  )
+  # Create some NULLs for R CMD Check
+  .original_row <- window_group <- action <- value <- order <- NULL
+  out$.original_row <- as.numeric(rownames(out))
+  if (replace_zeros) {
+    out <- out |>
+      dplyr::mutate(
+        dplyr::across(
+          dplyr::all_of(cols), ~ifelse(. == 0, NA, .)
+        )
+      )
+  }
+  out <- out |>
+    dplyr::arrange(.original_row) |>
+    dplyr::mutate(window_group = ceiling(seq_len(n) / window_size))
+  out_names <- colnames(data)
+  extra_cols <- out_names[!(out_names %in% c(cols, id_cols))]
+  out |>
+    tidyr::pivot_longer(
+      cols = dplyr::all_of(cols),
+      names_to = "action",
+      values_to = "value"
+    ) |>
+    dplyr::filter(!is.na(value)) |>
+    dplyr::arrange(.original_row, action) |>
+    dplyr::group_by(
+      dplyr::across(
+        dplyr::all_of(c("window_group", id_cols))
+      )
+    ) |>
+    dplyr::mutate(order = dplyr::row_number()) |>
+    dplyr::ungroup() |>
+    dplyr::arrange(
+      dplyr::across(
+        dplyr::all_of(c(id_cols, "window_group", "order"))
+      )
+    ) |>
+    dplyr::select(
+      dplyr::all_of(extra_cols),
+      dplyr::all_of(id_cols),
+      action,
+      value,
+      order
+    )
+}
