@@ -1,6 +1,7 @@
 #' Plot a Histogram of Edge Weights in the Network
 #'
 #' @export
+#' @family basic
 #' @inheritParams graphics::hist
 #' @param ... Additional arguments passed to [graphics::hist()].
 #' @param main A `character` string defining the title of the plot.
@@ -61,18 +62,21 @@ hist.tna <- function(x, breaks, col = "lightblue",
 #' the edge weights of the network.
 #'
 #' @export
-#' @family core
+#' @family basic
 #' @param x A `tna` object from [tna()].
+#' @param labels See [qgraph::qgraph()].
 #' @param colors See [qgraph::qgraph()].
+#' @param pie See [qgraph::qgraph()].
+#' @param cut Edge color and width emphasis cutoff value. The default is
+#' the median of the edge weights. See [qgraph::qgraph()] for details.
 #' @param show_pruned A `logical` value indicating if pruned edges removed by
 #' [prune()] should be shown in the plot.  The default is `TRUE`, and the
 #' edges are drawn as dashed with a different color to distinguish them.
 #' @param pruned_edge_color A `character` string for the color to use for
-#' pruned edges when `show_pruned = TRUE`. The default is `"red"`.
+#' pruned edges when `show_pruned = TRUE`. The default is `"pink"`.
 #' @param edge.color See [qgraph::qgraph()].
 #' @param edge.labels See [qgraph::qgraph()].
 #' @param edge.label.position See [qgraph::qgraph()].
-#' @param labels See [qgraph::qgraph()].
 #' @param layout One of the following:
 #'   * A `character` string describing a `qgraph` layout.
 #'   * A `matrix` of node positions to use, with a row for each node and
@@ -81,7 +85,6 @@ hist.tna <- function(x, breaks, col = "lightblue",
 #' @param layout_args A `list` of arguments to pass to the `igraph` layout
 #'   function when `layout` is a function.
 #' @param mar See [qgraph::qgraph()].
-#' @param pie See [qgraph::qgraph()].
 #' @param theme See [qgraph::qgraph()].
 #' @param ... Additional arguments passed to [qgraph::qgraph()].
 #' @return A `qgraph` plot of the transition network.
@@ -89,8 +92,8 @@ hist.tna <- function(x, breaks, col = "lightblue",
 #' model <- tna(group_regulation)
 #' plot(model)
 #'
-plot.tna <- function(x, labels, colors, pie,
-                     show_pruned = TRUE, pruned_edge_color = "red",
+plot.tna <- function(x, labels, colors, pie, cut,
+                     show_pruned = TRUE, pruned_edge_color = "pink",
                      edge.color = NA, edge.labels = TRUE,
                      edge.label.position = 0.65, layout = "circle",
                      layout_args = list(), mar = rep(5, 4),
@@ -114,6 +117,9 @@ plot.tna <- function(x, labels, colors, pie,
       attr(x$data, "colors")
     )
   }
+  if (missing(cut)) {
+    cut <- stats::median(x$weights, na.rm = TRUE)
+  }
   lty <- 1
   if (!is.null(attr(x, "pruning")) && show_pruned) {
     lty <- x$weights
@@ -141,10 +147,29 @@ plot.tna <- function(x, labels, colors, pie,
     pie = pie,
     mar = mar,
     lty = lty,
+    cut = cut,
     ...
   )
 }
 
+#' Plot a Bootstrapped Transition Network Analysis Model
+#'
+#' @export
+#' @family validation
+#' @param x A `tna_bootstrap` object.
+#' @param ... Additional arguments passed to [plot.tna()].
+#' @examples
+#' model <- tna(group_regulation)
+#' # Small number of iterations for CRAN
+#' boot <- bootstrap(model, iter = 50)
+#' plot(boot)
+#'
+plot.tna_bootstrap <- function(x, ...) {
+  check_missing(x)
+  check_class(x, "tna_bootstrap")
+  plot(x$model, ...)
+}
+
 #' Plot Centrality Measures
 #'
 #' Plots the centrality measures of a `tna_centralities` object as a
@@ -154,7 +179,7 @@ plot.tna <- function(x, labels, colors, pie,
 #' [centralities()] for details on the centrality measures.
 #'
 #' @export
-#' @family core
+#' @family centralities
 #' @param x An object of class `tna_centralities`.
 #' @param ncol Number of columns to use for the facets. The default is 3.
 #' @param scales Either `"fixed"` or `"free_x"` (the default). If `"free_x"`,
@@ -184,6 +209,7 @@ plot.tna_centralities <- function(x, reorder = TRUE, ncol = 3,
 #' Plot Cliques of a TNA Network
 #'
 #' @export
+#' @family cliques
 #' @inheritParams print.tna_cliques
 #' @inheritParams plot.tna
 #' @param cut See [qgraph::qgraph()].
@@ -254,10 +280,6 @@ plot.tna_cliques <- function(x, n = 6, first = 1, show_loops = FALSE,
     )
     plot_args <- utils::modifyList(plot_args, list(...))
     do.call(qgraph::qgraph, args = plot_args)
-    # TODO should already work with 1 clique?
-    # if ((max_cliques - first) == 0) {
-    #  return (do.call(qgraph::qgraph, args = plot_args))
-    # }
   }
   invisible(NULL)
 }
@@ -269,7 +291,7 @@ plot.tna_cliques <- function(x, n = 6, first = 1, show_loops = FALSE,
 #' color mappings.
 #'
 #' @export
-#' @family patterns
+#' @family communities
 #' @param x A `communities` object generated by the `find_communities` method.
 #' Each community detection method maps nodes or points in to a specific
 #' communities.
@@ -303,10 +325,10 @@ plot.tna_communities <- function(x, colors, method = "spinglass", ...) {
   plot(y, colors = map_to_color(x$assignment[[method]], colors), ...)
 }
 
-#' Plot the results of comparing two `tna` models or matrices
+#' Plot the Comparison of Two TNA Models or Matrices
 #'
 #' @export
-#' @family patterns
+#' @family comparison
 #' @param x A `tna_comparison` object.
 #' @param type A `character` string naming the type of plot to produce. The
 #' available options are `"heatmap"` (the default), `"scatterplot"`,
@@ -465,9 +487,14 @@ plot.tna_comparison <- function(x, type = "heatmap",
 #' Plot the Significant Differences from a Permutation Test
 #'
 #' @export
+#' @family validation
 #' @param x A `tna_permutation` object.
 #' @param colors See [qgraph::qgraph()].
 #' @param ... Arguments passed to [plot_model()].
+#' @param posCol Color for plotting edges
+#'   the difference in edge weights is positive. See [qgraph::qgraph()].
+#' @param negCol Color for plotting edges when
+#'   the the difference in edge weights is negative. See [qgraph::qgraph()].
 #' @return A `qgraph` object containing only the significant edges according
 #' to the permutation test.
 #' @examples
@@ -477,7 +504,9 @@ plot.tna_comparison <- function(x, type = "heatmap",
 #' perm <- permutation_test(model_x, model_y, iter = 20)
 #' plot(perm)
 #'
-plot.tna_permutation <- function(x, colors, ...) {
+plot.tna_permutation <- function(x, colors,
+                                 posCol = "#009900", negCol = "red", ...) {
+  check_missing(x)
   check_class(x, "tna_permutation")
   colors <- ifelse_(
     missing(colors),
@@ -488,6 +517,8 @@ plot.tna_permutation <- function(x, colors, ...) {
     x$edges$diffs_sig,
     labels = attr(x, "labels"),
     colors = colors,
+    posCol = posCol,
+    negCol = negCol,
     ...
   )
 }
@@ -500,6 +531,7 @@ plot.tna_permutation <- function(x, colors, ...) {
 #' along with their confidence intervals (CIs).
 #'
 #' @export
+#' @family validation
 #' @param x A `tna_stability` object produced by `estimate_cs`.
 #' @param level A `numeric` value representing the significance level for
 #' the confidence intervals. Defaults to `0.05`.
@@ -542,13 +574,6 @@ plot.tna_stability <- function(x, level = 0.05, ...) {
   for (i in seq_along(x)) {
     measure <- x_names[i]
     corr <- x[[measure]]$correlations
-    # TODO Check if measure_results has valid dimensions?
-    # if (is.null(dim(corr)) || nrow(corr) == 0 || ncol(corr) == 0) {
-    #   warning_(
-    #     paste0("Warning: No valid data for measure ", measure, ". Skipping.")
-    #   )
-    #   next
-    # }
     means <- apply(corr, 2L, mean, na.rm = TRUE)
     ci_lower <- apply(
       corr,
@@ -642,7 +667,7 @@ plot_centralities_ <- function(x, reorder, ncol, scales, colors, labels) {
     colors <- rep(colors, length.out = length(unique(x$state)))
   }
   ifelse_(
-    is_tna_centralities(x),
+    inherits(x, "tna_centralities"),
     plot_centralities_single(x, reorder, ncol, scales, colors, labels),
     plot_centralities_multiple(x, reorder, ncol, scales, colors, labels)
   )
@@ -653,34 +678,38 @@ plot_centralities_ <- function(x, reorder, ncol, scales, colors, labels) {
 #' @inheritParams plot.tna_centralities
 #' @noRd
 plot_centralities_single <- function(x, reorder, ncol, scales, colors, labels) {
+  # Create some NULLs for R CMD Check
+  name <- value <- NULL
+  levs <- names(x)[-1L]
   x <- stats::reshape(
     as.data.frame(x),
     idvar = "state",
     ids = x[["state"]],
-    times = names(x)[-1L],
+    times = levs,
     timevar = "name",
     drop = "state",
-    varying = list(names(x)[-1L]),
+    varying = list(levs),
     direction = "long",
     v.names = "value"
-  )
-  x <- ifelse_(
-    reorder,
-    dplyr::arrange(
-      x, !!rlang::sym("name"), !!rlang::sym("value")
-    ),
-    dplyr::arrange(
-      x, !!rlang::sym("name"), dplyr::desc(!!rlang::sym("state"))
+  ) |>
+    dplyr::group_by(name) |>
+    dplyr::mutate(
+      prop = value / sum(value, na.rm = TRUE),
+      name = factor(name, levels = levs)
     )
+  n_measures <- length(levs)
+  state_within_name <- paste(x$state, x$name, sep = "___")
+  x$state_within <- ifelse_(
+    reorder,
+    stats::reorder(state_within_name, x$value, FUN = identity),
+    x$state
   )
-  x$rank <- dplyr::row_number(x)
-
   ggplot2::ggplot(x) +
     ggplot2::scale_fill_manual(values = colors) +
     ggplot2::geom_col(
       ggplot2::aes(
         fill = !!rlang::sym("state"),
-        x = !!rlang::sym("rank"),
+        x = !!rlang::sym("state_within"),
         y = !!rlang::sym("value")
       ),
       linewidth = 4
@@ -690,21 +719,18 @@ plot_centralities_single <- function(x, reorder, ncol, scales, colors, labels) {
       labels,
       ggplot2::geom_text(
         ggplot2::aes(
-          label = round(!!rlang::sym("value"), 2),
-          x = !!rlang::sym("rank"),
-          y = 0.98 * !!rlang::sym("value")
+          label = paste0(" ", round(!!rlang::sym("value"), 2), " "),
+          x = !!rlang::sym("state_within"),
+          y = !!rlang::sym("value"),
+          hjust = !!rlang::sym("prop") > 0.05
         ),
-        vjust = 0.3,
-        hjust = 1,
+        vjust = 0.35,
         size = 3
       )
     ) +
     ggplot2::facet_wrap(~name, ncol = ncol, scales = scales) +
-    ggplot2::scale_x_continuous(
-      name = NULL,
-      expand = c(0, 0.5),
-      breaks = x$rank,
-      labels = x$state
+    ggplot2::scale_x_discrete(
+      labels = function(y) gsub("___.+$", "", y)
     ) +
     ggplot2::theme_minimal() +
     ggplot2::theme(
@@ -726,7 +752,7 @@ plot_centralities_multiple <- function(x, reorder, ncol,
   measures <- names(x)[3:ncol(x)]
   n_clusters <- length(unique(x$group))
   x$state <- factor(x$state)
-  x |>
+  x <- x |>
     data.frame() |>
     stats::reshape(
       varying = measures,
@@ -734,8 +760,9 @@ plot_centralities_multiple <- function(x, reorder, ncol,
       timevar = "name",
       times = measures,
       direction = "long"
-    ) |>
-    ggplot2::ggplot(
+    )
+  x$name <- factor(x$name, levels = measures)
+  ggplot2::ggplot(x,
       ggplot2::aes(
         x = !!rlang::sym("value"),
         y = !!rlang::sym("state"),
@@ -760,13 +787,16 @@ plot_centralities_multiple <- function(x, reorder, ncol,
     ggplot2::theme_minimal() +
     ggplot2::xlab("Centrality") +
     ggplot2::ylab("") +
+    ggplot2::labs(color = "", fill = "") +
     ggplot2::theme(
+      strip.text = ggplot2::element_text(face = "bold", size = 12),
       panel.spacing = ggplot2::unit(1, "lines"),
+      axis.text.y = ggplot2::element_text(size = 8, vjust = 0.2),
       legend.position = "bottom"
     )
 }
 
-#' Plot the difference network between two models
+#' Plot the Difference Network Between Two Models
 #'
 #' Plots the difference network between model `x` and model `y`. The edges are
 #' computed from subtracting the two models. The pie chart is the difference in
@@ -774,12 +804,16 @@ plot_centralities_multiple <- function(x, reorder, ncol,
 #' that `x`is greater than `y`and red indicates otherwise.
 #'
 #' @export
-#' @family core
-#' @param x A `tna` object. It will be the principal model.
-#' @param y A `tna` object. It will be the model subtracted from the
+#' @family comparison
+#' @param x A `tna` object. This is the the principal model.
+#' @param y A `tna` object. This is the model subtracted from the
 #'   principal model.
 #' @param theme See [qgraph::qgraph()].
 #' @param palette See [qgraph::qgraph()].
+#' @param posCol Color for plotting edges and pie when
+#'   the first group has a higher value. See [qgraph::qgraph()].
+#' @param negCol Color for plotting edges and pie when
+#'   the second group has a higher value. See [qgraph::qgraph()].
 #' @param ... Additional arguments passed to [qgraph::qgraph()].
 #' @return A `qgraph` object displaying the difference network between the
 #'   two models.
@@ -794,18 +828,16 @@ plot_compare <- function(x, ...) {
 
 #' @export
 #' @rdname plot_compare
-plot_compare.tna <- function(x, y, theme = NULL, palette = "colorblind", ...) {
+plot_compare.tna <- function(x, y, theme = NULL, palette = "colorblind",
+                             posCol = "#009900", negCol = "red", ...) {
   check_class(x, "tna")
   check_class(y, "tna")
-  # TODO check that x and y are comparable
   stopifnot_(
     all(x$labels == y$labels),
     "{.arg x} and {.arg y} must have the same labels."
   )
   pie <- abs(x$inits - y$inits)
-  piesign <- ifelse(x$inits > y$inits, "#009900", "red")
-  # pos_col <- c("#009900", "darkgreen")
-  # neg_col <- c("#BF0000", "red")
+  piesign <- ifelse(x$inits > y$inits, posCol, negCol)
   diff <- build_model_(
     x$weights - y$weights,
     type = attr(x, "type"),
@@ -820,10 +852,57 @@ plot_compare.tna <- function(x, y, theme = NULL, palette = "colorblind", ...) {
     pieColor = piesign,
     palette = palette,
     theme = theme,
+    posCol = posCol,
+    negCol = negCol,
     ...
   )
 }
 
+#' Plot the Frequency Distribution of States
+#'
+#' @export
+#' @family basic
+#' @param x A `tna` object created from sequence data.
+#' @param ... Ignored.
+#' @return A `ggplot` object.
+#' @examples
+#' model <- tna(group_regulation)
+#' plot_frequencies(model)
+#'
+plot_frequencies <- function(x, ...) {
+  UseMethod("plot_frequencies")
+}
+
+#' @export
+#' @rdname plot_frequencies
+plot_frequencies.tna <- function(x, ...) {
+  check_missing(x)
+  check_tna_seq(x)
+  #cols <- attr(x$data, "cols")
+  #tab <- table(unlist(x$data[, cols]))
+  tab <- table(unlist(x$data))
+  d <- as.data.frame(tab)
+  names(d) <- c("state", "freq")
+  d[[1L]] <- factor(x$labels[d[[1L]]])
+  ggplot2::ggplot(
+    d,
+    ggplot2::aes(x = !!rlang::sym("state"), y = !!rlang::sym("freq"))
+  ) +
+    ggplot2::geom_bar(
+      stat = "identity",
+      colour = "black",
+      width = 0.7
+    ) +
+    ggplot2::geom_text(
+      ggplot2::aes(label = !!rlang::sym("freq")),
+      position = ggplot2::position_dodge(width = 0.7),
+      vjust = -0.5
+    ) +
+    ggplot2::theme_minimal() +
+    ggplot2::scale_y_continuous(expand = ggplot2::expansion(mult = c(0, .1))) +
+    ggplot2::labs(x = "State", y = "Frequency")
+}
+
 #' Plot a Transition Network Model from a Matrix of Edge Weights
 #'
 #' @export
@@ -835,7 +914,7 @@ plot_compare.tna <- function(x, y, theme = NULL, palette = "colorblind", ...) {
 #' m <- matrix(rexp(25), 5, 5)
 #' plot_model(m)
 #'
-plot_model <- function(x, labels, colors,
+plot_model <- function(x, labels, colors, cut,
                        edge.labels = TRUE, edge.label.position = 0.65,
                        layout = "circle", layout_args = list(),
                        mar = rep(5, 4), theme = "colorblind", ...) {
@@ -850,6 +929,9 @@ plot_model <- function(x, labels, colors,
   if (missing(colors)) {
     colors <- color_palette(nc)
   }
+  if (missing(cut)) {
+    cut <- stats::median(x, na.rm = TRUE)
+  }
   layout <- check_layout(x, layout, layout_args)
   qgraph::qgraph(
     input = x,
@@ -860,13 +942,15 @@ plot_model <- function(x, labels, colors,
     layout = layout,
     theme = theme,
     mar = mar,
+    cut = cut,
     ...
   )
 }
 
-#' Create a mosaic plot of transitions
+#' Create a Mosaic Plot of Transitions or Events
 #'
 #' @export
+#' @family basic
 #' @param x A `tna` or a `group_tna` object.
 #' @param digits An `integer` that determines the number of digits to use
 #' for the chi-square test statistic and the p-value in the plot.
@@ -883,8 +967,6 @@ plot_mosaic <- function(x, ...) {
 #' @export
 #' @rdname plot_mosaic
 plot_mosaic.tna <- function(x, digits = 1, ...) {
-  # from https://stackoverflow.com/questions/19233365/how-to-create-a-marimekko-mosaic-plot-in-ggplot2,
-  # Based on the code by Jake Fisher and cpsyctc.
   check_missing(x)
   check_class(x, "tna")
   stopifnot_(
@@ -900,6 +982,8 @@ plot_mosaic.tna <- function(x, digits = 1, ...) {
   )
 }
 
+# from https://stackoverflow.com/questions/19233365/how-to-create-a-marimekko-mosaic-plot-in-ggplot2,
+# Based on the code by Jake Fisher and cpsyctc.
 plot_mosaic_ <- function(tab, digits, title, xlab, ylab) {
   n <- nrow(tab)
   m <- ncol(tab)
@@ -970,6 +1054,7 @@ plot_mosaic_ <- function(tab, digits, title, xlab, ylab) {
     ggplot2::scale_x_continuous(
       breaks = unique(d$xcent),
       labels = dimnames(tab)[[1]],
+      position = "top",
       expand = c(0.01, 0)
     ) +
     ggplot2::scale_y_continuous(
@@ -984,14 +1069,17 @@ plot_mosaic_ <- function(tab, digits, title, xlab, ylab) {
       plot.subtitle = ggplot2::element_text(hjust = 0.5),
       axis.ticks = ggplot2::element_blank(),
       axis.line = ggplot2::element_blank(),
-      axis.text.x = ggplot2::element_text(angle = 90, hjust = 1, vjust = 0.5),
+      axis.text.x =  ggplot2::element_text(
+        angle =  ifelse(n > 3, 90, 0),
+        hjust =  ifelse(n > 3, 0, 0.5),
+        vjust =  ifelse(n > 3, 0.5, 0)
+      ),
       axis.text.y = ggplot2::element_text(hjust = 1, vjust = 0.40)
     ) +
     ggplot2::labs(x = xlab, y = ylab)
   out
 }
 
-
 #' Create a heatmap from edgelist data
 #'
 #' @param data A `data.frame` with source and target columns and edge weights.
@@ -1027,7 +1115,7 @@ create_heatmap <- function(data, title) {
 #' Plot a Histogram of Edge Weights for a `group_tna` Object.
 #'
 #' @export
-#' @family clusters
+#' @family basic
 #' @param x A `group_tna` object.
 #' @param ... Additional arguments passed to [graphics::hist()].
 #' @return A `list` (invisibly) of `histogram` objects of the edge weights of
@@ -1042,22 +1130,24 @@ hist.group_tna <- function(x, ...) {
   invisible(lapply(x, hist.tna, ...))
 }
 
-#' Plot a grouped Transition Network Analysis Model
+#' Plot a Grouped Transition Network Analysis Model
 #'
 #' Plots a transition network of each cluster using `qgraph`.
 #'
 #' @export
-#' @family clusters
+#' @family basic
 #' @param x A `group_model` object.
 #' @param title A title for each plot. It can be a single string (the same one
 #'  will be used for all plots) or a list (one per group)
+#' @param which An optional `integer` vector of groups to plot. By default, all
+#' groups are plotted.
 #' @param ... Same as [plot.tna()].
 #' @return `NULL` (invisibly).
 #' @examples
 #' model <- group_model(engagement_mmm)
 #' plot(model)
 #'
-plot.group_tna <- function(x, title, ...) {
+plot.group_tna <- function(x, title, which, ...) {
   check_missing(x)
   check_class(x, "group_tna")
   if (missing(title)) {
@@ -1065,16 +1155,39 @@ plot.group_tna <- function(x, title, ...) {
   } else if (length(title) == 1) {
     title <- rep(title, length(x))
   }
-  for (i in seq_along(x)) {
+  which <- ifelse_(missing(which), seq_along(x), which)
+  stopifnot_(
+    all(which %in% seq_along(x)),
+    "Argument {.arg which} must only contain valid cluster indices."
+  )
+  for (i in which) {
     plot(x[[i]], title = title[i], ...)
   }
   invisible(NULL)
 }
 
+#' Plot a Bootstrapped Grouped Transition Network Analysis Model
+#'
+#' @export
+#' @family validation
+#' @param x A `group_tna_bootstrap` object.
+#' @param ... Additional arguments passed to [plot.tna()].
+#' @examples
+#' model <- group_model(engagement_mmm)
+#' # Small number of iterations for CRAN
+#' boot <- bootstrap(model, iter = 50)
+#' plot(boot)
+#'
+plot.group_tna_bootstrap <- function(x, ...) {
+  check_missing(x)
+  check_class(x, "group_tna_bootstrap")
+  invisible(lapply(x, plot.tna_bootstrap, ...))
+}
+
 #' Plot Centrality Measures
 #'
 #' @export
-#' @family clusters
+#' @family centralities
 #' @param x A `group_tna_centralities` object.
 #' @inheritParams plot.tna_centralities
 #' @return A `ggplot` object displaying a line chart for each centrality
@@ -1095,7 +1208,7 @@ plot.group_tna_centralities <- function(x, reorder = TRUE, ncol = 3,
 #' Plot Found Cliques
 #'
 #' @export
-#' @family clusters
+#' @family cliques
 #' @param x A `group_tna_cliques` object.
 #' @param title A `character` vector of titles to use for each plot.
 #' @param ... Arguments passed to [plot.tna_cliques()].
@@ -1105,7 +1218,7 @@ plot.group_tna_centralities <- function(x, reorder = TRUE, ncol = 3,
 #' @examples
 #' model <- group_model(engagement_mmm)
 #' cliq <- cliques(model, size = 2)
-#' plot(cliq, ask = F)
+#' plot(cliq, ask = FALSE)
 #'
 plot.group_tna_cliques <- function(x, title, ...) {
   check_missing(x)
@@ -1120,10 +1233,10 @@ plot.group_tna_cliques <- function(x, title, ...) {
   )
 }
 
-#' Plot Found Communities
+#' Plot Detected Communities
 #'
 #' @export
-#' @family clusters
+#' @family communities
 #' @param x A `group_tna_communities` object.
 #' @param title A `character` vector of titles to use for each plot.
 #' @param colors A `character` vector of colors to use.
@@ -1167,7 +1280,7 @@ plot.group_tna_communities <- function(x, title = names(x), colors, ...) {
 #' Plot Centrality Stability Results
 #'
 #' @export
-#' @family clusters
+#' @family validation
 #' @param x A `group_tna_stability` object.
 #' @param ... Arguments passed to [plot.tna_stability()].
 #' @return A `list` (invisibly) of `ggplot` objects displaying the stability
@@ -1188,10 +1301,43 @@ plot.group_tna_stability <- function(x, ...) {
   invisible(lapply(x, plot.tna_stability, ...))
 }
 
-#' Plot the difference network between two clusters
+#' Plot Permutation Test Results
 #'
 #' @export
-#' @family clusters
+#' @family validation
+#' @param x A `group_tna_permutation` object.
+#' @param title An optional `character` vector of titles for each plot.
+#' When not provided, the title shows the names of the clusters being
+#' contrasted.
+#' @param ... Arguments passed to [plot.tna_permutation()].
+#' @return A `list` (invisibly) of `qgraph` objects depicting the significant
+#' difference between each pair.
+#' @examples
+#' model <- group_tna(engagement_mmm)
+#' # Small number of iterations for CRAN
+#' perm <- permutation_test(model, iter = 20)
+#' plot(perm)
+#'
+plot.group_tna_permutation <- function(x, title, ...) {
+  check_missing(x)
+  check_class(x, "group_tna_permutation")
+  title <- ifelse_(
+    missing(title),
+    names(x),
+    title
+  )
+  invisible(
+    lapply(
+      seq_along(x),
+      function(i) plot.tna_permutation(x[[i]], title = title[i])
+    )
+  )
+}
+
+#' Plot the Difference Network Between Two Clusters
+#'
+#' @export
+#' @family comparison
 #' @param x A `group_tna` object.
 #' @param i An `integer` index or the name of the principal cluster as a
 #' `character` string.
@@ -1211,10 +1357,59 @@ plot_compare.group_tna <- function(x, i = 1L, j = 2L, ...) {
   plot_compare(x = x[[i]], y = x[[j]], ...)
 }
 
-#' Plot state frequencies as a mosaic between two groups
+#' Plot the Frequency Distribution of States
 #'
 #' @export
-#' @family clusters
+#' @family basic
+#' @param x A `group_tna` object.
+#' @param label An optional `character` string that can be provided to specify
+#' the grouping factor name if `x` was not constructed using a column name of
+#' the original data.
+#' @param ... Ignored.
+#' @return A `ggplot` object.
+#' @examples
+#' model <- group_model(engagement_mmm)
+#' plot_frequencies(model)
+#'
+plot_frequencies.group_tna <- function(x, label, ...) {
+  check_missing(x)
+  check_class(x, "group_tna")
+  combined <- combine_data(x, label)
+  long <- combined$data
+  label <- combined$label
+  long$value <- factor(x[[1L]]$labels[long$value])
+  long[[label]] <- factor(long[[label]])
+  d <- long |>
+    dplyr::group_by(!!rlang::sym(label), !!rlang::sym("value")) |>
+    dplyr::summarize(freq = dplyr::n())
+  ggplot2::ggplot(
+    d,
+    ggplot2::aes(
+      x = !!rlang::sym("value"),
+      y = !!rlang::sym("freq"),
+      fill = !!rlang::sym(label))
+  ) +
+    ggplot2::geom_bar(
+      stat = "identity",
+      colour = "black",
+      position = ggplot2::position_dodge(),
+      width = 0.7
+    ) +
+    ggplot2::geom_text(
+      ggplot2::aes(label = !!rlang::sym("freq")),
+      position = ggplot2::position_dodge(width = 0.7),
+      vjust = -0.5
+    ) +
+    ggplot2::scale_fill_brewer(palette = "Set2") +
+    ggplot2::theme_minimal() +
+    ggplot2::scale_y_continuous(expand = ggplot2::expansion(mult = c(0, .1))) +
+    ggplot2::labs(x = "State", y = "Frequency")
+}
+
+#' Plot State Frequencies as a Mosaic Between Two Groups
+#'
+#' @export
+#' @family basic
 #' @param x A `tna_data` object.
 #' @param digits An `integer` that determines the number of digits to use
 #' for the chi-square test statistic and the p-value in the plot.
@@ -1279,10 +1474,10 @@ plot_mosaic.tna_data <- function(x, group, label = "Group", digits = 1, ...) {
   )
 }
 
-#' Plot state frequencies as a mosaic between two groups
+#' Plot State Frequencies as a Mosaic Between Two Groups
 #'
 #' @export
-#' @family clusters
+#' @family basic
 #' @param x A `group_tna` object.
 #' @param label An optional `character` string that can be provided to specify
 #' the grouping factor name if `x` was not constructed using a column name of
@@ -1295,33 +1490,16 @@ plot_mosaic.tna_data <- function(x, group, label = "Group", digits = 1, ...) {
 #' plot_mosaic(model)
 #'
 plot_mosaic.group_tna <- function(x, label, digits = 1, ...) {
+  check_missing(x)
   check_class(x, "group_tna")
-  cols <- attr(x, "cols")
+  check_values(digits, strict = TRUE)
+  combined <- combine_data(x, label)
+  long <- combined$data
+  label <- combined$label
   labels <- x[[1L]]$labels
-  levs <- attr(x, "levels")
-  groups <- attr(x, "groups")
-  group_var <- attr(x, "group_var")
-  data <- dplyr::bind_rows(
-    lapply(x, function(y) y$data[, cols])
-  )
-  data[[group_var]] <- unlist(groups)
-  label <- ifelse_(
-    !missing(label),
-    label,
-    ifelse_(
-      group_var == ".group",
-      "Cluster",
-      group_var
-    )
-  )
-  check_string(label)
-  names(data) <- c(names(data)[-ncol(data)], label)
-  long <- data |>
-    tidyr::pivot_longer(cols = !(!!rlang::sym(label))) |>
-    dplyr::filter(!is.na(!!rlang::sym("value")))
   use_na <- ifelse_(attr(x, "na.rm"), "no", "ifany")
   tab <- table(long[[label]], long$value, useNA = use_na)
-  dimnames(tab) <- list(levs, labels)
+  dimnames(tab) <- list(attr(x, "levels"), labels)
   plot_mosaic_(
     tab,
     digits,
