@@ -22,12 +22,23 @@ mock_sequence <- data.frame(
   T5 = c("C", "A", "B", "B")
 )
 
+mock_sequence_wide <- data.frame(
+  ID = c("A", "A", "B", "B"),
+  Time = c(1, 2, 1, 2),
+  feature1 = c(10, 0, 15, 20),
+  feature2 = c(5, 8, 0, 12),
+  feature3 = c(2, 4, 6, 8),
+  other_col = c("X", "Y", "Z", "W")
+)
+
 # A mock tna object
 mock_tna <- tna(
   x = mock_matrix,
   inits = c(0.3, 0.2, 0.3, 0.2)
 )
 
+mock_tna_seq <- tna(mock_sequence)
+
 mmm_model <- group_tna(engagement_mmm)
 
 mock_long <- data.frame(
